pub struct DeviceTrack {
pub track: Track,
pub usb_path: String,
pub anlz_dir: String,
pub anlz_index: u16,
pub file_size: u64,
pub sample_depth: u16,
pub file_type: u16,
pub bitrate: u32,
pub sample_rate: u32,
}Expand description
A track as it will exist on the stick.
Fields
track: Trackusb_path: String/Contents/...
anlz_dir: String/PIONEER/USBANLZ/Pxxx/xxxxxxxx
anlz_index: u16N of ANLZ000N.*: tracks whose paths hash to the same anlz_dir
are numbered in export order, the way rekordbox does it.
file_size: u64sample_depth: u16file_type: u16bitrate: u32sample_rate: u32Implementations